==> 2.3.0.tar.gz: oddmuse/modules/translations/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
use utf8;
$ModulesDescription .= '<p><a href="http://git.savannah.gnu.org/cgit/oddmuse.git/tree/modules/translations/fixme-utf8.pl">fixme-utf8.pl</a>, see <a href="http://www.oddmuse.org/cgi-bin/oddmuse/Fixme">Fixme</a></p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Include normal pages

Reading not allowed: user, ip, or network is blocked.

Login

Error

%s calls

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Journal

More...

Comments on this page

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

CGI Internal error: %s

Invalid action parameter %s

Page name is missing

Page name is too long: %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Too many redirections

No redirection for old revisions

Invalid link pattern for #REDIRECT

Please go on to %s.

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days

List later changes

RSS

RSS with pages

RSS with pages and diff

Filters

Title:

Title and Body:

Username:

Host:

Follow up to:

Language:

Go!

(minor)

rollback

new

All changes for %s

from %s

This page is too big to send over RSS.

History of %s

Compare

Deleted

Mark this page for deletion

No other revisions available

current

Revision %s

Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.

Rollback to %s

%s rolled back

to %s

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]

redirected from %s

%s: 

Click to search for references to this page

Cookie: 

Edit this page

Preview:

Preview only, not yet saved

Warning

Database is stored in temporary directory %s

%s seconds

Last edited

Edited

by %s

(diff)

Edit revision %s of this page

e

This page is read-only

View other revisions

View current revision

View all changes

View contributors

Homepage URL:

s

Save

p

Preview

Search:

f

Replace:

Delete

Validate HTML

Validate CSS

Last edit

Difference between revision %1 and %2

revision %s

current revision

Last major edit (%s)

later minor edits

No diff available.

Old revision:

Changed:

Deleted:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Cancel

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Filter:

(for %s)

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

last updated

by

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Moving %s log entries.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Debugging Information

Inter links:

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Complete Content

The main page is %s.

Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

The search parameter is missing.

Pages link to %s

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List

List of locked pages

Pages tagged with %s

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Locked Pages

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Invalid Mail %s: not saved.

unsubscribe

subscribe

Email: 

%s appears to be an invalid mail address

Your mail subscriptions

All mail subscriptions

Subscriptions

Show

Subscriptions for %s:

Unsubscribe

There are no subscriptions for %s.

Change email address

Mail addresses are linked to unsubscription links.

Subscribe to %s.

Subscribe

Subscribed %s to the following pages:

The remaining pages do not exist.

Unsubscribed %s from the following pages:

You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.

%s is not a legal name for a namespace

Namespaces

Getting page index file for %s.

Near links:

Search sites on the %s as well

Fetching results from %s:

Near pages:

Include near pages

EditNearLinks

The same page on other sites:

 (create locally)

image

download

Backlinks

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

OpenID Login

Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

Your homepage is set to %s.

You have no homepage set.

Homepage:

Homepage is missing

OpenID error %s

Orphan List

Trail: 

None

Type

Permalink to "%s"

anchor first defined here: %s

the page %s also exists

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Click to search for references to this permanent anchor

Include permanent anchors

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

Please type the following two words:

Please answer this captcha:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

New Pages for Indexed Search

List changes since %s

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Page list for %s

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Feed for this tag

Rebuild tag index

list tags

tag cloud

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents

Create a new page for today

Add Translation

Added translation: %1 (%2)

Translate %s

Thank you for writing a translation of %s.

Please indicate what language you will be using.

Language is missing

Suggested languages:

Please indicate a page name for the translation of %s.

More help may be available here: %s.

Translated page: 

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION

==> 2.3.1.tar.gz: oddmuse/modules/translations/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
use utf8;
AddModuleDescription('fixme-utf8.pl', 'Fixme');
%Translate = split(/\n/,<<'END_OF_TRANSLATION');
This page is empty.

Add your comment here:

Reading not allowed: user, ip, or network is blocked.

Login

Error

%s calls

Cannot create %s

Include normal pages

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Journal

More...

Comments on this page

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

CGI Internal error: %s

Invalid action parameter %s

Page name is missing

Page name is too long: %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Too many redirections

No redirection for old revisions

Invalid link pattern for #REDIRECT

Please go on to %s.

Updates since %s

up to %s

Updates in the last %s days

Updates in the last day

for %s only

List latest change per page only

List all changes

Skip rollbacks

Include rollbacks

List only major changes

Include minor changes

%s days

List later changes

RSS

RSS with pages

RSS with pages and diff

Filters

Title:

Title and Body:

Username:

Host:

Follow up to:

Language:

Go!

(minor)

rollback

new

All changes for %s

This page is too big to send over RSS.

History of %s

Compare

Deleted

Mark this page for deletion

No other revisions available

current

Revision %s

Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.

Rollback of %s would restore banned content.

Rollback to %s

%s rolled back

to %s

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

from %s

[Home]

redirected from %s

%s: 

Click to search for references to this page

Cookie: 

Edit this page

Preview:

Preview only, not yet saved

Warning

Database is stored in temporary directory %s

%s seconds

Last edited

Edited

by %s

(diff)

a

c

Edit revision %s of this page

e

This page is read-only

View other revisions

View current revision

View all changes

View contributors

Homepage URL:

s

Save

p

Preview

Search:

f

Replace:

Delete

Validate HTML

Validate CSS

Last edit

Summary:

Difference between revision %1 and %2

revision %s

current revision

Last major edit (%s)

later minor edits

No diff available.

Old revision:

Changed:

Deleted:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

unlock the wiki

Could not get %s lock

The lock was created %s.

Maybe the user running this script is no longer allowed to remove the lock directory?

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

This change is a minor edit.

Cancel

Replace this file with text

Replace this text with a file

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Filter:

(for %s)

%s pages found.

Malformed regular expression in %s

Replaced: %s

Search for: %s

View changes for these pages

last updated

by

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Moving %s log entries.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Debugging Information

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

, see 

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Attach file:

Upload

Learn more...

Complete Content

The main page is %s.

Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

The search parameter is missing.

Pages link to %s

Ban contributors

Ban Contributors to %s

%s is banned

Ban!

These URLs were rolled back. Perhaps you want to add a regular expression to %s?

Regular expression:

Consider banning the IP number as well: 

Regular expression "%1" matched "%2" on this page.

Regular expression "%s" matched on this page.

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments:

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Install CSS

Copy one of the following stylesheets to %s:

Reset

Extract all dates from the database

Dates

No dates found.

Inter links:

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Page diff

Diff

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Fix character encoding

Fix HTML escapes

Set $FormTimeoutSalt.

Form Timeout

GD or Image::Magick modules not available.

GD::SecurityImage module not available.

Image storing failed. (%s)

Bad gd_security_image_id.

Please type the six characters from the anti-spam image

Submit

CAPTCHA

You did not answer correctly.

$GdSecurityImageFont is not set.

No summary provided

no summary available

page was marked for deletion

Oddmuse

Cleaning up git repository

Email: 

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

The username %s already exists.

The email address %s has already been used.

Wait %s minutes before try again.

Registration Confirmation

Visit the link blow to confirm registration.

Recover Account

You can login by following the link below. Then set new password.

Change Email Address

To confirm changing email address, follow the link below.

To submit this form you must answer this question:

Question:

CAPTCHA:

Registration

The username must be valid page name.

Confirmation email will be sent to the email address.

Repeat Password:

Email:

Bad email address format.

Password needs to have at least %s characters.

Passwords differ.

Email Sent

Confirmation email has been sent to %s. Visit the link on the mail to confirm registration.

Failed to Confirm Registration

Invalid key.

The key expired.

Registration Confirmed

Now, you can login by using username and password.

Forgot your password?

Login failed.

You are banned.

You must confirm email address.

Logged in

%s has logged in.

You should set new password immediately.

Change Password

Logged out

%s has logged out.

Account Settings

Logout

Current Password:

New Password:

Repeat New Password:

Password is wrong.

Password Changed

Your password has been changed.

Forgot Password

Enter email address, and recovery login ticket will be sent.

Not found.

The mail address is not valid anymore.

An email has been sent to %s with further instructions.

New Email Address:

Failed to load account.

An email has been sent to %s with a login ticket.

Confirmation Failed

Failed to confirm.

Email Address Changed

Email address for %1 has been changed to %2.

Account Management

Ban Account

Enter username of the account to ban:

Ban

Enter username of the account to unban:

Unban

%s is already banned.

%s has been banned.

%s is not banned.

%s has been unbanned.

Register

Languages:

Show!

Define

Full Link List

Banned Content

Rule "%1" matched on this page.

List of locked pages

Pages tagged with %s

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Name: 

URL: 

Define Local Names

Define external redirect: 

IP number matched %s

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Who am I?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Invalid Mail %s: not saved.

unsubscribe

subscribe

%s appears to be an invalid mail address

Your mail subscriptions

All mail subscriptions

Subscriptions

Show

Subscriptions for %s:

Unsubscribe

There are no subscriptions for %s.

Change email address

Mail addresses are linked to unsubscription links.

Subscribe to %s.

Subscribe

Subscribed %s to the following pages:

The remaining pages do not exist.

Unsubscribed %s from the following pages:

Migrating Subscriptions

No non-migrated email addresses found, migration not necessary.

Migrated %s rows.

Update modules

Module Updater

You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.

%s is not a legal name for a namespace

Namespaces

Getting page index file for %s.

Near links:

Search sites on the %s as well

Fetching results from %s:

Near pages:

Include near pages

EditNearLinks

The same page on other sites:

 (create locally)

image

download

Backlinks

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Make available offline

Offline

You are currently offline and what you requested is not part of the offline application. You need to be online to do this.

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

anchor first defined here: %s

the page %s also exists

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Click to search for references to this permanent anchor

Include permanent anchors

Portrait

This page is password protected. If you know the password, you can %s. Once you have done that, return and reload this page.

supply the password now

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

Upload is limited to %s bytes

To save this page you must answer this question:

Please type the following two words:

Please answer this captcha:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

New Pages for Indexed Search

List changes since %s

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Page list for %s

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Edit image in the browser

Summary of your changes: 

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Feed for this tag

Rebuild tag index

list tags

tag cloud

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

thumb

Error creating thumbnail from non existant page %s.

Can not create thumbnail for file type %s.

Can not create thumbnail for a text document

Could not open %s for writing whilst trying to save image before creating thumbnail. Check write permissions.

Can not create path for thumbnail - %s

Failed to run %1 to create thumbnail: %2

%s ran into an error

%s produced no output

Failed to parse %s.

Timezone

Pick your timezone:

Set

Contents

Create a new page for today

Add Translation

Please provide a different page name for the translation.

Added translation: %1 (%2)

Translate %s

Thank you for writing a translation of %s.

Please indicate what language you will be using.

Language is missing

Suggested languages:

Please indicate a page name for the translation of %s.

More help may be available here: %s.

Translated page: 

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

Upgrading Database

Did the previous upgrade end with an error? A lock was left behind.

Unlock wiki

Upgrade complete.

Upgrade complete. Please remove $ModuleDir/upgade.pl, now.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Web application for offline browsing

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
